<?php

add_action('admin_init', 'atfc_generate_csv');

/**
 * Process content of CSV file
 *
 * @since 0.1
 * */
function atfc_generate_csv()
{

    if (isset($_POST['_wpnonce-atfc-voting-data-export'])) {

        check_admin_referer('atfc-voting-data-export', '_wpnonce-atfc-voting-data-export');

        global $wpdb;

        $atfc_data_table = $wpdb->prefix . "atfc_data"; // for deatils. each day info.

        $product_id = $_POST['atfc_products']; // Get post ID 

        $atfc_id = $_POST['atfc_attachment_title']; // Get post ID

        $atfc_filtered_data = array();

        if ($atfc_id == "") {

            // Then we are going to add display each item 
            //        $product_id = $_POST['product_id'];

            $atfc_attachments = get_post_meta($product_id, 'atfc_attachments', true);


            if (!empty($atfc_attachments)) {

                foreach ($atfc_attachments as $key => $value) {

                    $product_wise_meta_key = $product_id . '_' . $value['atfc_id'] . '_atfc_dload';

                    $file = $value['atfc_url'];

                    if ($file != "") {

                        $file_info = basename($file);

                        $atfc_dload = get_post_meta($product_id, $product_wise_meta_key, true);

                        array_push($atfc_filtered_data, array(
                            isset($_POST['product_title']) ? $_POST['product_title'] : $product_id,
                            $file_info,
                            ($atfc_dload == "") ? 0 : $atfc_dload,
                            '-',
                        ));
                    }
                }
            } else {

                //                $post_data['status'] = 0;
            }
        } else {

            $vars = array($product_id, $atfc_id);
            $con_atfc_date_range_filters = "";

            if (isset($_POST['atfc_custom_date_range'])) {

                $atfc_custom_date_range = $_POST['atfc_custom_date_range']; // Get Custom Date range status.
                $atfc_filter_start_date = $_POST['atfc_filter_start_date']; // Starting date of filter.
                $atfc_filter_end_date = $_POST['atfc_filter_end_date']; // Ending date of filter.
                // End of total votes count.



                if ($atfc_custom_date_range == "true") {
                    $atfc_filter_start_date = ($atfc_filter_start_date == "") ? "2010-04-01" : $atfc_filter_start_date;
                    $atfc_filter_end_date = ($atfc_filter_end_date == "") ? "2020-04-01" : $atfc_filter_end_date;

                    $con_atfc_date_range_filters .= " AND DATE(dload_date) >= %s AND DATE(dload_date) <= %s ";

                    $vars[] = $atfc_filter_start_date;
                    $vars[] = $atfc_filter_end_date;
                }
            }
            $mv_btn_del_string = " - ";


            // Only count the total votes. ( Summary )

            $sql = $wpdb->prepare("SELECT postid, atfc_id, atfc_dload, ip_dload,dload_date  FROM {$atfc_data_table}   
                WHERE postid = %d 
                AND atfc_id = %s 
                " . $con_atfc_date_range_filters . "
                ORDER BY ID DESC", $vars);


            // Generate data from query.

            $atfc_dload_data = $wpdb->get_results($sql, ARRAY_A);

            if (sizeof($atfc_dload_data) > 0) :

                foreach ($atfc_dload_data as $dload_data) :

                    //            $post_id = $dload_data['postid'];
                    // End of backend total vote counting.

                    array_push($atfc_filtered_data, array(
                        isset($_POST['product_title']) ? $_POST['product_title'] : $dload_data['postid'],
                        isset($_POST['atfc_title']) ? $_POST['atfc_title'] : $dload_data['postid'],
                        $dload_data['atfc_dload'],
                        $dload_data['dload_date'],
                        $dload_data['ip_dload'],
                    ));

                endforeach;

            endif;

            wp_reset_query();
        }

        $output_file_name = 'atfc_data.' . date('Y-m-d-H-i-s') . '.csv';

        header('Content-Description: File Transfer');
        header('Content-Disposition: attachment; filename=' . $output_file_name);
        header('Content-Type: text/csv; charset=' . get_option('blog_charset'), true);

        $input_array = $atfc_filtered_data;

        $delimiter = ',';

        /** open raw memory as file, no need for temp files, be careful not to run out of memory thought */
        $f = fopen('php://memory', 'w');
        /** loop through array  */
        foreach ($input_array as $line) {
            /** default php csv handler **/
            fputcsv($f, $line, $delimiter);
        }
        /** rewrind the "file" with the csv lines **/
        fseek($f, 0);
        /** modify header to be downloadable csv file **/
        header('Content-Type: application/csv');
        header('Content-Disposition: attachement; filename="' . $output_file_name . '";');
        /** Send file to browser for download */
        fpassthru($f);
        exit;
    }
}

add_action('wp_ajax_atfc_get_item_lists_data', 'atfc_get_item_lists_data');

function atfc_get_item_lists_data()
{

    $product_id = $_POST['product_id'];

    $atfc_attachments = get_post_meta($product_id, 'atfc_attachments', true);

    $atfc_attachments = atfc_get_global_attachments($atfc_attachments);

    $post_data = array();

    if (!empty($atfc_attachments)) {

        $post_data['status'] = 1;

        foreach ($atfc_attachments as $key => $value) {

            $product_wise_meta_key = $product_id . '_' . $value['atfc_id'] . '_atfc_dload';

            $file =  $value['atfc_url'];

            if ($file != "") {

                $file_info = basename($file);

                $ext = pathinfo($file, PATHINFO_EXTENSION);

                $file_size = atfc_human_filesize(atfc_remote_file_size($file), 2);

                $atfc_dload = get_post_meta($product_id, $product_wise_meta_key, true);

                $post_data['data'][] = array(
                    'atfc_id' => $value['atfc_id'],
                    'atfc_url' => $value['atfc_url'],
                    'atfc_title' => $file_info,
                    'atfc_size' => $file_size,
                    'atfc_type' => $ext,
                    'atfc_dload' => ($atfc_dload == "") ? 0 : $atfc_dload
                );
            }
        }
    } else {

        $post_data['status'] = 0;
    }

    echo json_encode($post_data);

    wp_reset_query();  //reset the query   

    die();
}


/***********************************************************************************************/
/* @ Description: Integrate Voting Report Submenu With Voting Manager Menu Section 
 * @ Since: 1.1.1
 * @ Introduced: 20-10-2015
 * @ Last Update: 06-11-2015
 *  */
/***********************************************************************************************/

add_action('admin_menu', 'atfc_voting_report_submenu');

function atfc_voting_report_submenu()
{

    $page = add_submenu_page(
        'bwl-atfc', // unique slug for plugin settings menu.
        esc_html__('Download Report Manager', 'bwl-atfc'), // The Text to be display in bte browser bar.
        esc_html__('Download Report', 'bwl-atfc'), // The Text to be display in bte browser bar.
        'manage_options', // Permission.,
        'atfc-download-report',
        'cbAtfcDownloadReportPage' // Settings Page,
    );

    /* Using registered $page handle to hook stylesheet loading */
    add_action('admin_print_styles-' . $page, 'atfc_report_page_styles');
}

function atfc_report_page_styles()
{
    /*
     * It will be called only on your plugin admin page, enqueue our stylesheet here
     */
    wp_enqueue_style('atfc-admin');
}

/* * ******************************************************************************************** */
/* Download Report Sub Menu Page */
/* * ******************************************************************************************** */

function cbAtfcDownloadReportPage()
{
    require_once BWL_ATFC_PLUGIN_PATH . '/includes/option-panel/views/download_report.php';
}


//@Description: Generate Download Data in data grid.
//@Since: Version 1.1.1

add_action('wp_ajax_atfc_download_stats', 'atfc_download_stats');

function atfc_download_stats()
{

    global $wpdb;

    $atfc_data_table = $wpdb->prefix . "atfc_data"; // for deatils. each day info.

    $product_id = $_POST['product_id']; // Get post ID 

    $atfc_id = $_POST['atfc_id']; // Get post ID

    $atfc_filtered_data = array();

    if ($atfc_id == "") {

        // Then we are going to add display each item 

        //        $product_id = $_POST['product_id'];

        $atfc_attachments = get_post_meta($product_id, 'atfc_attachments', true);

        if (!empty($atfc_attachments)) {

            foreach ($atfc_attachments as $key => $value) {

                $product_wise_meta_key = $product_id . '_' . $value['atfc_id'] . '_atfc_dload';

                $file =  $value['atfc_url'];

                if ($file != "") {

                    $file_info = basename($file);

                    $atfc_dload = get_post_meta($product_id, $product_wise_meta_key, true);

                    array_push($atfc_filtered_data, array(

                        isset($_POST['product_title']) ? $_POST['product_title'] : $product_id,
                        $file_info,
                        ($atfc_dload == "") ? 0 : $atfc_dload,
                        '-',
                        '-'
                    ));
                }
            }
        } else {

            //                $post_data['status'] = 0;

        }

        $data = array(
            'aaData' => $atfc_filtered_data
        );
        echo json_encode($data);

        die();
    }

    $atfc_custom_date_range = $_POST['atfc_custom_date_range']; // Get Custom Date range status.
    $atfc_filter_start_date = $_POST['atfc_filter_start_date']; // Starting date of filter.
    $atfc_filter_end_date = $_POST['atfc_filter_end_date']; // Ending date of filter.

    // End of total votes count.

    $vars = array($product_id, $atfc_id);

    $con_atfc_date_range_filters = "";

    if ($atfc_custom_date_range == "true") {
        $atfc_filter_start_date = ($atfc_filter_start_date == "") ? "2010-04-01" : $atfc_filter_start_date;
        $atfc_filter_end_date = ($atfc_filter_end_date == "") ? "2020-04-01" : $atfc_filter_end_date;

        $con_atfc_date_range_filters .= " AND DATE(dload_date) >= %s AND DATE(dload_date) <= %s ";

        $vars[] = $atfc_filter_start_date;
        $vars[] = $atfc_filter_end_date;
    }

    $mv_btn_del_string = " - ";


    // Only count the total votes. ( Summary )

    $sql = $wpdb->prepare("SELECT postid, atfc_id, atfc_dload, ip_dload,dload_date  FROM {$atfc_data_table}   
                WHERE postid = %d 
                AND atfc_id = %s 
                " . $con_atfc_date_range_filters . "
                ORDER BY ID DESC", $vars);


    // Generate data from query.

    $atfc_dload_data = $wpdb->get_results($sql, ARRAY_A);

    if (sizeof($atfc_dload_data) > 0) :

        foreach ($atfc_dload_data as $dload_data) :

            //            $post_id = $dload_data['postid'];

            // End of backend total vote counting.

            array_push($atfc_filtered_data, array(

                isset($_POST['product_title']) ? $_POST['product_title'] : $dload_data['postid'],
                isset($_POST['atfc_title']) ? $_POST['atfc_title'] : $dload_data['postid'],
                $dload_data['atfc_dload'],
                $dload_data['dload_date'],
                $dload_data['ip_dload']
            ));

        endforeach;

    endif;

    wp_reset_query();

    $data = array(
        'aaData' => $atfc_filtered_data
    );
    echo json_encode($data);

    die();
}
