<?php

/**
 * @Description: Shortcode for Generating Attachment items for product tab.
 * @Since: Version 1.0.0
 * @Author: Mahbub
 * @Last Update:11-04-2016
 */

add_shortcode('bwl_atfc', 'cb_bwl_atfc');

if (!function_exists('cb_bwl_atfc')) {

    function cb_bwl_atfc($atts)
    {

        $atts = shortcode_atts(array(
            'product_id' => 0,
            'status' => 1,
            'atfc_view_type' => 'box_view'
        ), $atts);

        extract($atts);

        $atfc_options = get_option('atfc_options');

        $bwl_atfc_content = "";
        //        $bwl_atfc_content .= "<h2>Available Attachments:</h2>";

        $atfc_login_requirement = 0;

        if (isset($atfc_options['atfc_login_status']) && $atfc_options['atfc_login_status'] == 1) {

            $atfc_login_requirement = 1;

            if (is_user_logged_in()) :

                $atfc_login_requirement = 0;

            endif;
        }

        if ($atfc_login_requirement == 1) {

            $bwl_atfc_content .= '<h4 class="atfc_login_required_msg"><i class="fa fa-info-circle"></i> ' . esc_html__("Login required to download attachments !", 'bwl-atfc') . '</h4>';
            $bwl_atfc_content .= do_shortcode('[aftc_login_form]');
            return $bwl_atfc_content;
        }


        $productAttachments = get_post_meta($product_id, 'atfc_attachments', true);

        // Global Attachment Integration.

        if (isset($atfc_options['atfc_global_attachment_status']) && $atfc_options['atfc_global_attachment_status'] == 1) {

            $productAttachments = atfc_get_global_attachments($productAttachments);
        }


        if (!empty($productAttachments)) {

            // File Size Display Condition.

            $atfc_display_file_size = 1;

            if (isset($atfc_options['atfc_display_file_size']) && $atfc_options['atfc_display_file_size'] == 1) {
                $atfc_display_file_size = 0;
            }

            // File Type Display Condition.

            $atfc_display_file_type = 1;

            if (isset($atfc_options['atfc_display_file_type']) && $atfc_options['atfc_display_file_type'] == 1) {
                $atfc_display_file_type = 0;
            }

            // Download Counter Display Condition.

            $atfc_display_download_counter = 1;

            if (isset($atfc_options['atfc_display_download_counter']) && $atfc_options['atfc_display_download_counter'] == 1) {
                $atfc_display_download_counter = 0;
            }

            // Download Counter Display Condition.

            $atfc_disable_force_download = 0;

            if (isset($atfc_options['atfc_disable_force_download']) && $atfc_options['atfc_disable_force_download'] == 1) {
                $atfc_disable_force_download = 1;
            }

            // File Type Icon Condition.

            $atfc_display_file_type_icon = 1;

            if (isset($atfc_options['atfc_display_file_type_icon']) && $atfc_options['atfc_display_file_type_icon'] == 1) {
                $atfc_display_file_type_icon = 0;
            }

            // Attachment View Type.

            $atfc_view_class = 'columns-2';

            if (isset($atfc_view_type) && $atfc_view_type == 'list_view') {

                $atfc_view_class = 'columns-1';
            }



            $mergedAttachmentsList = [];

            foreach ($productAttachments as $key => $value) {

                $product_wise_meta_key = $product_id . '_' . $value['atfc_id'] . '_atfc_dload';

                $file = $value['atfc_url'];

                if ($file != "") {

                    $file_info = basename($file);

                    if ($atfc_display_file_size == 1) {
                        $file_size = atfc_human_filesize(atfc_remote_file_size($file), 2);
                    } else {
                        $file_size = "";
                    }

                    if ($atfc_display_file_type == 1) {
                        $ext = pathinfo($file, PATHINFO_EXTENSION);
                    } else {
                        $ext = "";
                    }

                    $atfc_dload = get_post_meta($product_id, $product_wise_meta_key, true);

                    $atfc_id = (!empty($value['atfc_id'])) ? $value['atfc_id'] : '';

                    $mergedAttachmentsList[] = array(
                        'atfc_id' => $atfc_id,
                        'atfc_url' => $value['atfc_url'],
                        'atfc_title' => $file_info,
                        'atfc_size' => $file_size,
                        'atfc_type' => $ext,
                        'atfc_dload' => ($atfc_dload == "") ? 0 : $atfc_dload
                    );
                }
            }


            $bwl_atfc_content .= ' <input value="" id="current_page" type="hidden"><input value="" id="show_per_page" type="hidden">';

            $bwl_atfc_content .= '<ul class="atfc_wrapper ' . $atfc_view_class . '">';

            // echo "<pre style='width: 100%;'>";
            // print_r($mergedAttachmentsList);
            // echo "</pre>";

            foreach ($mergedAttachmentsList as $key => $value) {

                $aftc_file_class = aftc_get_file_class($value['atfc_type']);

                $atfc_id = (!empty($value['atfc_id'])) ? $value['atfc_id'] : '';



                $atfc_download_link = (!empty($atfc_id)) ? get_bloginfo('url') . '?id=' . $product_id . '&&atfc=' . $atfc_id : $value['atfc_url'];

                $atfc_external_file = ($atfc_id == "") ? 1 : 0;

                // Generate File Size HTML.

                if ($atfc_display_file_size == 0) {
                    $atfc_file_size_string = '';
                } else {
                    $atfc_file_size_string = '<p><strong>' . esc_html__('Size:', 'bwl-atfc') . '</strong> ' . $value['atfc_size'] . '</p>';
                }

                // Generate File Type HTML.

                if ($atfc_display_file_type == 0) {
                    $atfc_display_file_type_string = '';
                } else {
                    $atfc_display_file_type_string = '<p><strong>' . esc_html__('Type:', 'bwl-atfc') . '</strong> ' . $value['atfc_type'] . '</p>';
                }

                // Generate Download Counter HTML.

                if ($atfc_display_download_counter == 0 || $atfc_external_file == 1) {
                    $atfc_download_counter_string = '';
                } else {
                    $atfc_download_counter_string = '<p><strong>' . esc_html__('Total download:', 'bwl-atfc') . ' </strong> ' . $value['atfc_dload'] . '</p>';
                }

                // Hide File Type Icon Class

                if ($atfc_display_file_type_icon == 0) {
                    $aftc_file_class = "class='none'";
                }

                // File Title & Custom File Title.

                $atfc_title = $value['atfc_title'];

                if (isset($atfc_options['atfc_custom_title_status']) && $atfc_options['atfc_custom_title_status'] == 1 && $atfc_external_file == 0) {

                    $atfc_media_custom_title = get_post_meta($atfc_id, 'atfc_media_custom_title', true);

                    $atfc_title = (empty($atfc_media_custom_title)) ? $atfc_title : trim($atfc_media_custom_title);
                }

                // Deactivate Download Feature addedi in version 1.0.7

                $atfc_download_new_window = "";

                if ($atfc_disable_force_download == 1) {
                    $atfc_download_link = $value['atfc_url'];
                    $atfc_download_new_window = " target='_blank'";
                }


                $bwl_atfc_content .= '<li ' . $aftc_file_class . '>
                                                           <h3><a href="' . trim($atfc_download_link) . '" ' . $atfc_download_new_window . '>' . trim($atfc_title) . ' <i class="fa fa-download"></i></a></h3>
                                                        ' . $atfc_file_size_string . '
                                                        ' . $atfc_display_file_type_string . '
                                                        ' . $atfc_download_counter_string . '
                                                   </li>';
            }

            $bwl_atfc_content .= '</ul>';

            $bwl_atfc_content .= '<div id="page_navigation"></div>';
        } else {

            $bwl_atfc_content .= esc_html__("Sorry, no attachment available !", 'bwl-atfc');
        }

        return $bwl_atfc_content;
    }
}

/**
 * @Description: Shortcode For Create Login Form
 * @Since: Version 1.0.0
 * @Author: Mahbub
 * @Last Update:11-04-2016
 */

add_shortcode('aftc_login_form', 'cb_aftc_login_form');

if (!function_exists('cb_aftc_login_form')) {

    function cb_aftc_login_form($atts, $content = null)
    {

        extract(shortcode_atts(array(
            'redirect' => ''
        ), $atts));

        $form = "";

        if (!is_user_logged_in()) {

            if ($redirect) {
                $redirect_url = $redirect;
            } else {
                $redirect_url = get_permalink();
            }

            $args = array(
                'echo' => false,
                'redirect' => $redirect_url,
                'form_id' => 'aftc_login_form',
                'label_username' => esc_html__('Username', 'bwl-atfc'),
                'label_password' => esc_html__('Password', 'bwl-atfc'),
                'label_remember' => esc_html__('Remember Me', 'bwl-atfc'),
                'label_log_in' => esc_html__('Log In', 'bwl-atfc'),
                'id_username' => 'user_login',
                'id_password' => 'user_pass',
                'id_remember' => 'rememberme',
                'id_submit' => 'wp-submit',
                'remember' => true,
                'value_username' => NULL,
                'value_remember' => false
            );

            $form = wp_login_form($args);
        }

        return $form;
    }
}

/**
 * @Description: Get File Icons Class
 * @Since: Version 1.0.0
 * @Author: Mahbub
 * @Last Update:11-04-2016
 */

if (!function_exists('aftc_get_file_class')) {

    function aftc_get_file_class($file_type = "")
    {

        if ($file_type == "jpg" || $file_type == "jpeg" || $file_type == "png" || $file_type == "gif" || $file_type == "bmp") {

            return "class='ft_img'";
        } else if ($file_type == "mov" || $file_type == "vid" || $file_type == "wmv" || $file_type == "mp4") {

            return "class='ft_mov'";
        } else if ($file_type == "mp3" || $file_type == "audio") {

            return "class='ft_aud'";
        } else if ($file_type == "pdf") {

            return "class='ft_pdf'";
        } else if ($file_type == "doc" || $file_type == "docx") {

            return "class='ft_doc'";
        } else if ($file_type == "txt" || $file_type == "csv") {

            return "class='ft_txt'";
        } else if ($file_type == "xls") {

            return "class='ft_excel'";
        } else if ($file_type == "zip") {

            return "class='ft_zip'";
        } else {
            return "";
        }
    }
}
